#set( $symbol_pound = '#' )
#set( $symbol_dollar = '$' )
#set( $symbol_escape = '\' )
package ${package}.level1;

import java.io.IOException;
import java.net.URL;
import javax.xml.transform.Source;
import javax.xml.transform.dom.DOMSource;
import ${package}.ErrorMessage;
import ${package}.ErrorMessageKeys;
import ${package}.SuiteAttribute;
import org.opengis.cite.validation.RelaxNGValidator;
import org.opengis.cite.validation.ValidationErrorHandler;
import org.testng.Assert;
import org.testng.ITestContext;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

/**
 * Includes various tests of capability 1.
 */
public class Capability1Tests {

    private Document testSubject;

    /**
     * Obtains the test subject from the ISuite context. The suite attribute
     * {@link ${package}.SuiteAttribute#TEST_SUBJECT} should
     * evaluate to a DOM Document node.
     * 
     * @param testContext
     *            The test (group) context.
     */
    @BeforeClass
    public void obtainTestSubject(ITestContext testContext) {
        Object obj = testContext.getSuite().getAttribute(
                SuiteAttribute.TEST_SUBJECT.getName());
        if ((null != obj) && Document.class.isAssignableFrom(obj.getClass())) {
            this.testSubject = Document.class.cast(obj);
        }
    }

    /**
     * Sets the test subject. This method is intended to facilitate unit
     * testing.
     *
     * @param testSubject A Document node representing the test subject or
     * metadata about it.
     */
    public void setTestSubject(Document testSubject) {
        this.testSubject = testSubject;
    }

    /**
     * Verifies the string is empty.
     */
    @Test
    public void isEmpty() {
        String str = "  foo   ";
        Assert.assertTrue(str.isEmpty(),
                ErrorMessage.get(ErrorMessageKeys.EMPTY_STRING));
    }

    /**
     * Checks the behavior of the trim function.
     */
    @Test
    public void trim() {
        String str = "  foo   ";
        Assert.assertTrue("foo".equals(str.trim()));
    }

    /**
     * Verify the test subject is a valid Atom feed.
     */
    @Test
    public void docIsValidAtomFeed() throws SAXException, IOException {
        URL schemaRef = getClass().getResource(
                "/org/opengis/cite/alpha/rnc/atom.rnc");
        RelaxNGValidator rngValidator = new RelaxNGValidator(schemaRef);
        Source xmlSource = (null != testSubject)
                ? new DOMSource(testSubject) : null;
        rngValidator.validate(xmlSource);
        ValidationErrorHandler err = rngValidator.getErrorHandler();
        Assert.assertFalse(err.errorsDetected(),
                ErrorMessage.format(ErrorMessageKeys.NOT_SCHEMA_VALID,
                err.getErrorCount(), err.toString()));
    }
}
