#set( $symbol_pound = '#' )
#set( $symbol_dollar = '$' )
#set( $symbol_escape = '\' )
<?xml version="1.0" encoding="UTF-8"?>
<ctl:package xmlns:ctl="http://www.occamlab.com/ctl"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:tns="http://www.opengis.net/cite/${ets-code}"
  xmlns:saxon="http://saxon.sf.net/"
  xmlns:tec="java:com.occamlab.te.TECore">

  <ctl:function name="tns:run-ets-${ets-code}">
		<ctl:param name="testRunArgs">A Document node containing test run arguments (as XML properties).</ctl:param>
		<ctl:return>The test results as a Source object (root node).</ctl:return>
		<ctl:description>Runs the ${ets-code} ${symbol_dollar}{version} test suite.</ctl:description>
		<ctl:java class="${package}.TestNGController" 
                  method="doTestRun" 
                  initialized="true">
		  <ctl:with-param name="outputDirPath" select="system-property('java.io.tmpdir')" />
		</ctl:java>
	</ctl:function>

   <ctl:suite name="tns:ets-${ets-code}-${symbol_dollar}{version}">
     <ctl:title>${ets-title}</ctl:title>
     <ctl:description>Describe scope of testing.</ctl:description>
     <ctl:starting-test>tns:Main</ctl:starting-test>
   </ctl:suite>
 
   <ctl:test name="tns:Main">
      <ctl:assertion>The test subject satisfies all applicable constraints.</ctl:assertion>
	  <ctl:code>
        <xsl:variable name="form-data">
           <ctl:form method="POST" width="800" height="600">
             <h2>${ets-title}</h2>
             <div class="scope" 
			      style="background:${symbol_pound}F0F8FF" bgcolor="${symbol_pound}F0F8FF">
               <p>The implementation under test (IUT) is checked against the following specifications:</p>
               <ul>
                 <li><a href="http://www.w3.org/TR/xml/">Extensible Markup Language (XML) 1.0</a>, 
				 Fifth Edition</li>
				 <li><a href="http://www.w3.org/TR/xmlbase/">XML Base</a>, Second Edition</li>
               </ul>
               <p>Two conformance levels are defined:</p>
               <ul>
                 <li>Level 1</li>
                 <li>Level 2</li>
               </ul>
             </div>
             <fieldset style="background:${symbol_pound}ccffff">
               <legend style="font-family: sans-serif; color: ${symbol_pound}000099; 
			                 background-color:${symbol_pound}F0F8FF; border-style: solid; 
                       border-width: medium; padding:4px">Implementation under test</legend>
               <p>
                 <label class="form-label" for="uri">
                   <h4 style="margin-bottom: 0.5em">Location of IUT (absolute http: or file: URI)</h4>
                 </label>
                 <input id="uri" name="uri" size="96" type="text" value="atom-feed.xml" />
               </p>
               <p>
                 <label class="form-label" for="level">Conformance class: </label>
                 <input id="level-1" type="radio" name="level" value="1" checked="checked" />
                 <label class="form-label" for="level-1"> Level 1 | </label>
                 <input id="level-2" type="radio" name="level" value="2" />
                 <label class="form-label" for="level-2"> Level 2</label>
               </p>
             </fieldset>
             <p>
               <input class="form-button" type="submit" value="Start"/>
               <input class="form-button" type="reset" value="Clear"/>
             </p>
           </ctl:form>
        </xsl:variable>
	    <xsl:variable name="test-run-props">
		    <properties version="1.0">
		      <entry key="iut"><xsl:value-of select="${symbol_dollar}form-data/values/value[@key='uri']"/></entry>
          <entry key="ics"><xsl:value-of select="${symbol_dollar}form-data/values/value[@key='level']"/></entry>
		    </properties>
		</xsl:variable>
    <xsl:variable name="test-results">
      <ctl:call-function name="tns:run-ets-${ets-code}">
			  <ctl:with-param name="testRunArgs" select="${symbol_dollar}test-run-props"/>
			</ctl:call-function>
		</xsl:variable>
    <xsl:variable name="testRunDir">
      <xsl:value-of select="tec:getTestRunDirectory(${symbol_dollar}te:core)"/>
    </xsl:variable>
    <xsl:call-template name="tns:testng-report">
      <xsl:with-param name="results" select="${symbol_dollar}test-results" />
      <xsl:with-param name="outputDir" select="${symbol_dollar}testRunDir" />
    </xsl:call-template>

    <xsl:variable name="total-failed">
      <xsl:value-of select="${symbol_dollar}test-results/testng-results/@failed"/>
    </xsl:variable>
        <ctl:message>
====================
Test results summary
====================
Failed: <xsl:value-of select="${symbol_dollar}total-failed"/>
Skipped: <xsl:value-of select="${symbol_dollar}test-results/testng-results/@skipped"/>
Passed: <xsl:value-of select="${symbol_dollar}test-results/testng-results/@passed"/>
--------------------

See detailed test report in the TE_BASE/users/<xsl:value-of 
select="concat(substring-after(${symbol_dollar}testRunDir, 'users/'), '/html/')" /> directory.
        </ctl:message>
        <xsl:if test="xs:integer(${symbol_dollar}total-failed) gt 0">
          <xsl:for-each select="${symbol_dollar}test-results//test-method[@status='FAIL' and not(@is-config='true')]">
            <ctl:message>
-----------
Test method <xsl:value-of select="./@name"/>: <xsl:value-of select=".//message"/>
		    </ctl:message>
		  </xsl:for-each>
		  <ctl:fail/>
        </xsl:if>
	  </ctl:code>
   </ctl:test>

  <xsl:template name="tns:testng-report">
    <xsl:param name="results" />
    <xsl:param name="outputDir" />
    <xsl:variable name="stylesheet" select="tec:findXMLResource(${symbol_dollar}te:core, '/testng-report.xsl')" />
    <xsl:variable name="reporter" select="saxon:compile-stylesheet(${symbol_dollar}stylesheet)" />
    <xsl:variable name="report-params" as="node()*">
      <xsl:element name="testNgXslt.outputDir">
        <xsl:value-of select="concat(${symbol_dollar}outputDir, '/html')" />
      </xsl:element>
    </xsl:variable>
    <xsl:copy-of select="saxon:transform(${symbol_dollar}reporter, ${symbol_dollar}results, ${symbol_dollar}report-params)" />
  </xsl:template>
</ctl:package>
